@@ -1,5 +1,8 @@
 from optparse import OptionParser
 from sys import exit, stderr
+from typing import Optional
+
+import typer
 
 from exclock import __VERSION__
 from exclock.mains.play_clock_main import main as play_clock_main
@@ -45,7 +48,7 @@ def get_option_parser():
     return parser
 
 
-def main() -> None:
+def main(clock_filename_mock=None, show_list_mock=False, time_mock=None) -> None:
     if not executable('xmessage') and not executable('terminal-notifier'):
         print('both xmessage and terminal-notifier not found.', file=stderr)
         exit(1)
@@ -54,14 +57,34 @@ def main() -> None:
         print('mplayer not found.', file=stderr)
         exit(1)
 
-    opt, args = get_option_parser().parse_args()
+    def _main(
+            show_version: bool = typer.Option(False, '-v', '--version', help='show version'),
+            clock_filename: Optional[str] = typer.Option(None, '-c', '--clock-name', help=''),
+            show_list: bool = typer.Option(
+                False, '-l', '--list', help='show clock names in your PC and exit'),
+            time_: Optional[str] = typer.Option(
+                None, '-t', '--time', help='Time which spends until or to specified'),
+            ring_filename: Optional[str] = typer.Option(
+                None, '-r', '--ring-filename', help='filename which is used for alarm'),
+            traceback: bool = typer.Option(False, '--trace', '--traceback', help='show traceback'),
+    ):
+        if clock_filename_mock:
+            clock_filename = clock_filename_mock
+        if show_list_mock:
+            show_list = show_list_mock
+        if time_mock:
+            time_ = time_mock
 
-    if opt.show_list:
-        show_list_main()
-    elif opt.time is not None:
-        specified_time_main(opt, args)
-    else:
-        play_clock_main(opt, args)
+        if show_version:
+            print(__VERSION__)
+        elif show_list:
+            show_list_main()
+        elif time_ is not None:
+            specified_time_main(time_, ring_filename)
+        else:
+            play_clock_main(clock_filename)
+
+    typer.run(_main)
 
 
 if __name__ == '__main__':
