@@ -4,9 +4,7 @@ from os.path import basename as _path_basename
 from pathlib import Path
 from shlex import quote
 from time import sleep as time_sleep
-from typing import Final, List, Optional, Tuple
-
-from ycontract import contract
+from typing import Callable, Final, List, Optional, Tuple
 
 DEFAULT_RING_FILENAME: Final[str] = 'ring.mp3'
 
@@ -56,12 +54,11 @@ def is_time_delta_str(s: str) -> bool:
     return s == ''
 
 
-def is_time_delta_cerberus_validate(field, value, error):
+def is_time_delta_cerberus_validate(field: str, value: str, error: Callable[..., None]) -> None:
     if not is_time_delta_str(value):
         error(field, 'Must be an time string')
 
 
-@contract(returns=lambda sec: sec >= 0)
 def get_time_delta_from_str(s: str) -> int:
     if s.isdigit():
         return int(s)
@@ -96,7 +93,6 @@ def is_specific_time_str(s: str) -> bool:
     return 0 <= sec < 60 and 0 <= min_ < 60
 
 
-@contract(is_specific_time_str, returns=lambda res: res[0] >= 0 and res[1] >= 0 and res[2] >= 0)
 def get_specific_time_from_str(s: str) -> Tuple[int, int, int]:
     number_strs = s.split(':')
     number_strs = [s.replace(' ', '') for s in number_strs]
@@ -108,11 +104,6 @@ def get_specific_time_from_str(s: str) -> Tuple[int, int, int]:
     return (hour, min_, sec)
 
 
-@contract(
-    lambda time_: time_[0] >= 0 and time_[1] >= 0 and time_[2] >= 0,
-    lambda now_: now_[0] >= 0 and now_[1] >= 0 and now_[2] >= 0,
-    returns=lambda sec: sec >= 0,
-)
 def convert_specific_time_to_time_delta(
         time_: Tuple[int, int, int], now_: Tuple[int, int, int]) -> int:
     sec = (time_[0] - now_[0]) * 60 * 60 + (time_[1] - now_[1]) * 60 + (time_[2] - now_[2])
@@ -168,7 +159,6 @@ def notify(title: str, message: str) -> None:
     os.system(cmd)
 
 
-@contract(lambda spend_sec: spend_sec >= 0)
 def notify_all(
     *,
     title: str,
